%% Bodeplot of JONSWAP and notch wave filters
%
% Created by Christoffer Ofstad, 20.02.2014

% Wavespec
clear
global sigma wo
wo = .3; 
Hs = 4.8; 
wmax = 3;
w = (0.0001:0.01:wmax)';
S = wavespec(7,[Hs,wo,3.3],w,0); 
sigma = sqrt(max(S));
lambda = lsqcurvefit('Slin',0.1,w,S);

%wave filters
figure
hm=bodeplot(tf(1,[1/wo 1]));
setoptions(hm,'PhaseVisible','off');
hold on
hm2=bodeplot(1/tf([2*lambda*sigma*wo 0],[1 2*lambda*wo wo^2]));
setoptions(hm2,'PhaseVisible','off');
hold on
hm3=bodeplot(tf(1,[10 1]));
setoptions(hm3,'PhaseVisible','off');
hold on
w0=.175;
lp2=tf(w0^2,[1 2*sin(pi/4)*w0 w0^2]);
hm4=bodeplot(lp2);
setoptions(hm4,'PhaseVisible','off');

p = getoptions(hm);
p.Xlabel.FontSize = 14;
p.Ylabel.FontSize = 14;
p.Title.FontSize = 14;
p.TickLabel.FontSize = 14;
p.xlim=[1e-3 10];
p.ylim=[-40 0];
setoptions(hm,p)


h_legend=legend('LP with \omega=.3 rad/s','Inverted JONSWAP approximation at \omega=.3 rad/s'...
      ,'LP with \omega=.1 rad/s','2-order LP with \omega=.175','Location','SouthWest');
set(h_legend,'FontSize',10)
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 2])
print -dpng plots\jonswap_bode.png -r300
  
