%% Wave Filter Case Study
%
% Created by: Christoffer Ofstad 15.01.2014
%
clear
%% Case 1
% Initialize model
simulation_model = ('sim_case_wf'); 
sim_length=500;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=0e5;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[0 0 0]';
constants.real_ice.varying.offset=[0 0 0]';
constants.real_ice.varying.timeon=0;
constants.real_ice.varying.timeoff=0;

% With WF before controller
constants.tauwavefilter.on=0;
constants.wavefilter.on=1;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test1WFeta=eta;
Test1WFtau=tau_actual;
ISE_Test1WF_eta=total_error(1:3);
ISE_Test1WF_tau=ISE_thruster.signals.values(end,:)';
Test1WFmax=max_error;

% With WF after controller
constants.wavefilter.on=0;
constants.tauwavefilter.on=1;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test1WFposteta=eta;
Test1WFposttau=tau_actual;
ISE_Test1WFpost_eta=total_error(1:3);
ISE_Test1WFpost_tau=ISE_thruster.signals.values(end,:)';
Test1WFpostmax=max_error;

% Without WF
constants.tauwavefilter.on=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test1noWFeta=eta;
Test1noWFtau=tau_actual;
ISE_Test1noWF_eta=total_error(1:3);
ISE_Test1noWF_tau=ISE_thruster.signals.values(end,:)';
Test1noWFmax=max_error;

%plots
figure
subplot(3,1,1)
plot(Test1noWFtau.time,Test1noWFtau.signals.values(:,1))
hold on
plot(Test1WFtau.time,Test1WFtau.signals.values(:,1),'r','Linewidth',2)
hold on
plot(Test1WFtau.time,Test1WFposttau.signals.values(:,1),'g','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_x (N)');set_font
h_legend=legend('Without wave filter','With  pre wave filter','With  post wave filter');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test1noWFtau.time,Test1noWFtau.signals.values(:,2))
hold on
plot(Test1WFtau.time,Test1WFtau.signals.values(:,2),'r','Linewidth',2)
hold on
plot(Test1WFtau.time,Test1WFposttau.signals.values(:,2),'g','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_y (N)');set_font

subplot(3,1,3)
plot(Test1noWFtau.time,Test1noWFtau.signals.values(:,3))
hold on
plot(Test1WFtau.time,Test1WFtau.signals.values(:,3),'r','Linewidth',2)
hold on
plot(Test1WFtau.time,Test1WFposttau.signals.values(:,3),'g','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)');set_font
saveas(gcf, 'figures\WFCase\Test1_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\WFCase1tau.png -r300

figure
subplot(3,1,1)
plot(Test1noWFeta.time,Test1noWFeta.signals.values(:,1)-Test1WFeta.signals.values(:,1))
hold on
plot(Test1noWFeta.time,Test1noWFeta.signals.values(:,1)-Test1WFposteta.signals.values(:,1),'r')
xlabel('Time (seconds)');ylabel('error in surge (meters)');set_font
h_legend=legend('pre-controller','post-controller');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test1noWFeta.time,Test1noWFeta.signals.values(:,2)-Test1WFeta.signals.values(:,2))
hold on
plot(Test1noWFeta.time,Test1noWFeta.signals.values(:,2)-Test1WFposteta.signals.values(:,2),'r')
xlabel('Time (seconds)');ylabel('error in sway (meters)');set_font

subplot(3,1,3)
plot(Test1noWFeta.time,Test1noWFeta.signals.values(:,3)-Test1WFeta.signals.values(:,3))
hold on
plot(Test1noWFeta.time,Test1noWFeta.signals.values(:,3)-Test1WFposteta.signals.values(:,3),'r')
xlabel('Time (seconds)');ylabel('error in yaw (deg)');set_font
saveas(gcf, 'figures\WFCase\Test1_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\WFCase1eta.png -r300

%% Case 2 
% Initialize model
simulation_model = ('sim_case_wf'); 
sim_length=500;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=0e5;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[4e4 4e4 4e6]';
constants.real_ice.varying.offset=[-2e5 3.5e5 5e6]';
constants.real_ice.varying.timeon=150;
constants.real_ice.varying.timeoff=300;

% With WF before controller
constants.tauwavefilter.on=0;
constants.wavefilter.on=1;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test2WFeta=eta;
Test2WFtau=tau_actual;
ISE_Test2WF_eta=total_error(1:3);
ISE_Test2WF_tau=ISE_thruster.signals.values(end,:)';
Test2WFmax=max_error;

% With WF after controller
constants.wavefilter.on=0;
constants.tauwavefilter.on=1;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test2WFposteta=eta;
Test2WFposttau=tau_actual;
ISE_Test2WFpost_eta=total_error(1:3);
ISE_Test2WFpost_tau=ISE_thruster.signals.values(end,:)';
Test2WFpostmax=max_error;

% Without WF
constants.tauwavefilter.on=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test2noWFeta=eta;
Test2noWFtau=tau_actual;
ISE_Test2noWF_eta=total_error(1:3);
ISE_Test2noWF_tau=ISE_thruster.signals.values(end,:)';
Test2noWFmax=max_error;

%plots
figure
subplot(3,1,1)
plot(Test2noWFtau.time,Test2noWFtau.signals.values(:,1))
hold on
plot(Test2WFtau.time,Test2WFtau.signals.values(:,1),'r','Linewidth',2)
hold on
plot(Test2WFtau.time,Test2WFposttau.signals.values(:,1),'g','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_x (N)');set_font
h_legend=legend('Without wave filter','With  pre wave filter','With  post wave filter');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test2noWFtau.time,Test2noWFtau.signals.values(:,2))
hold on
plot(Test2WFtau.time,Test2WFtau.signals.values(:,2),'r','Linewidth',2)
hold on
plot(Test2WFtau.time,Test2WFposttau.signals.values(:,2),'g','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_y (N)');set_font

subplot(3,1,3)
plot(Test2noWFtau.time,Test2noWFtau.signals.values(:,3))
hold on
plot(Test2WFtau.time,Test2WFtau.signals.values(:,3),'r','Linewidth',2)
hold on
plot(Test2WFtau.time,Test2WFposttau.signals.values(:,3),'g','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)');set_font
saveas(gcf, 'figures\WFCase\Test2_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\WFCase2tau.png -r300

figure
subplot(3,1,1)
plot(Test2noWFeta.time,Test2noWFeta.signals.values(:,1)-Test2WFeta.signals.values(:,1))
hold on
plot(Test2noWFeta.time,Test2noWFeta.signals.values(:,1)-Test2WFposteta.signals.values(:,1),'r')
xlabel('Time (seconds)');ylabel('error in surge (meters)');set_font
h_legend=legend('pre-controller','post-controller');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test2noWFeta.time,Test2noWFeta.signals.values(:,2)-Test2WFeta.signals.values(:,2))
hold on
plot(Test2noWFeta.time,Test2noWFeta.signals.values(:,2)-Test2WFposteta.signals.values(:,2),'r')
xlabel('Time (seconds)');ylabel('error in sway (meters)');set_font

subplot(3,1,3)
plot(Test2noWFeta.time,Test2noWFeta.signals.values(:,3)-Test2WFeta.signals.values(:,3))
hold on
plot(Test2noWFeta.time,Test2noWFeta.signals.values(:,3)-Test2WFposteta.signals.values(:,3),'r')
xlabel('Time (seconds)');ylabel('error in yaw (deg)');set_font
saveas(gcf, 'figures\WFCase\Test2_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\WFCase2eta.png -r300

%% Case 3
% Initialize model
simulation_model = ('sim_case_wf'); 
sim_length=800;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=0e5;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[4e4 4e4 4e6]';
constants.real_ice.varying.offset=[-2e5 3.5e5 5e6]';
constants.real_ice.varying.timeon=150;
constants.real_ice.varying.timeoff=300;

% With WF before controller
constants.tauwavefilter.on=0;
constants.selective.on=1;
constants.selective.settle_time=50;
constants.wavefilter.on=1;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test3WFeta=eta;
Test3WFtau=tau_actual;
ISE_Test3WF_eta=total_error(1:3);
ISE_Test3WF_tau=ISE_thruster.signals.values(end,:)';
Test3WFmax=max_error;

% With WF after controller
constants.wavefilter.on=0;
constants.tauwavefilter.on=1;
sim(simulation_model);
Test3WFposteta=eta;
Test3WFFposttau=tau_actual;
[total_error, max_error] = error_sampling(eta, ISE_eta);
ISE_Test3WFpost_eta=total_error(1:3);
ISE_Test3WFpost_tau=ISE_thruster.signals.values(end,:)';
Test3WFpostmax=max_error;

% Without WF
constants.tauwavefilter.on=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test3noWFeta=eta;
Test3noWFtau=tau_actual;
ISE_Test3noWF_eta=total_error(1:3);
ISE_Test3noWF_tau=ISE_thruster.signals.values(end,:)';
Test3noWFmax=max_error;

%plots
figure
subplot(3,1,1)
plot(Test3noWFtau.time,Test3noWFtau.signals.values(:,1))
hold on
plot(Test3WFtau.time,Test3WFtau.signals.values(:,1),'r','Linewidth',1)
hold on
plot(Test3WFtau.time,Test3WFFposttau.signals.values(:,1),'g','Linewidth',1)
xlabel('Time (seconds)');ylabel('\tau_x (N)');set_font
h_legend=legend('Without wave filter','With selective pre wave filter','With selective post wave filter');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test3noWFtau.time,Test3noWFtau.signals.values(:,2))
hold on
plot(Test3WFtau.time,Test3WFtau.signals.values(:,2),'r','Linewidth',1)
hold on
plot(Test3WFtau.time,Test3WFFposttau.signals.values(:,2),'g','Linewidth',1)
xlabel('Time (seconds)');ylabel('\tau_y (N)');set_font

subplot(3,1,3)
plot(Test3noWFtau.time,Test3noWFtau.signals.values(:,3))
hold on
plot(Test3WFtau.time,Test3WFtau.signals.values(:,3),'r','Linewidth',1)
hold on
plot(Test3WFtau.time,Test3WFFposttau.signals.values(:,3),'g','Linewidth',1)
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)');set_font
saveas(gcf, 'figures\WFCase\Test3_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\WFCase3tau.png -r300

figure
subplot(3,1,1)
plot(Test3noWFeta.time,Test3noWFeta.signals.values(:,1)-Test3WFeta.signals.values(:,1))
hold on
plot(Test3noWFeta.time,Test3noWFeta.signals.values(:,1)-Test3WFposteta.signals.values(:,1),'r')
xlabel('Time (seconds)');ylabel('error in surge (meters)');set_font
h_legend=legend('pre-controller','post-controller');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test3noWFeta.time,Test3noWFeta.signals.values(:,2)-Test3WFeta.signals.values(:,2))
hold on
plot(Test3noWFeta.time,Test3noWFeta.signals.values(:,2)-Test3WFposteta.signals.values(:,2),'r')
xlabel('Time (seconds)');ylabel('error in sway (meters)');set_font

subplot(3,1,3)
plot(Test3noWFeta.time,Test3noWFeta.signals.values(:,3)-Test3WFeta.signals.values(:,3))
hold on
plot(Test3noWFeta.time,Test3noWFeta.signals.values(:,3)-Test3WFposteta.signals.values(:,3),'r')
xlabel('Time (seconds)');ylabel('error in yaw (deg)');set_font
saveas(gcf, 'figures\WFCase\Test3_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\WFCase3eta.png -r300

%% Case 4
% Initialize model
simulation_model = ('sim_case_wf'); 
sim_length=800;
init
clc
find_available_thrust

%Constant Ice Force applied
F_ice=0e5;
displacement=[40 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=200;

%Varying Ice Force applied
constants.real_ice.varying.force=[5e5 5e5 5e7]';
constants.real_ice.varying.offset=[-5e5 3e5 8e6]';
constants.real_ice.varying.timeon=150;
constants.real_ice.varying.timeoff=350;

% With WF
constants.tauwavefilter.on=0;
constants.wavefilter.on=1;
sim(simulation_model);
[~, max_error] = error_sampling(eta, ISE_eta);
Test4WFeta=eta;
Test4WFtau=tau_actual;
Test4WFmax=max_error;

% With selective WF before controller
constants.selective.on=1;
constants.selective.settle_time=50;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
ISE_Test4WFsel_eta=total_error(1:3);
ISE_Test4WFsel_tau=ISE_thruster.signals.values(end,:)';
Test4WFselmax=max_error;

% With selective WF after controller
constants.wavefilter.on=0;
constants.tauwavefilter.on=1;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
ISE_Test4WFselpost_eta=total_error(1:3);
ISE_Test4WFselpost_tau=ISE_thruster.signals.values(end,:)';
Test4WFselpostmax=max_error;

% Without WF
constants.tauwavefilter.on=0;
sim(simulation_model);
[total_error, max_error] = error_sampling(eta, ISE_eta);
Test4noWFeta=eta;
Test4noWFtau=tau_actual;
ISE_Test4noWF_eta=total_error(1:3);
ISE_Test4noWF_tau=ISE_thruster.signals.values(end,:)';
Test4noWFmax=max_error;

%plots
figure
subplot(3,1,1)
plot(Test4noWFtau.time,Test4noWFtau.signals.values(:,1))
hold on
plot(Test4WFtau.time,Test4WFtau.signals.values(:,1),'r','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_x (N)');set_font
h_legend=legend('Without wave filter','With wave filter');
set(h_legend,'FontSize',10)

subplot(3,1,2)
plot(Test4noWFtau.time,Test4noWFtau.signals.values(:,2))
hold on
plot(Test4WFtau.time,Test4WFtau.signals.values(:,2),'r','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_y (N)');set_font

subplot(3,1,3)
plot(Test4noWFtau.time,Test4noWFtau.signals.values(:,3))
hold on
plot(Test4WFtau.time,Test4WFtau.signals.values(:,3),'r','Linewidth',2)
xlabel('Time (seconds)');ylabel('\tau_{\psi} (Nm)');set_font
saveas(gcf, 'figures\WFCase\Test4_tau', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\WFCase4tau.png -r300

figure
subplot(3,1,1)
plot(Test4noWFeta.time,Test4noWFeta.signals.values(:,1)-Test4WFeta.signals.values(:,1))
xlabel('Time (seconds)');ylabel('error in surge (meters)');set_font

subplot(3,1,2)
plot(Test4noWFeta.time,Test4noWFeta.signals.values(:,2)-Test4WFeta.signals.values(:,2))
xlabel('Time (seconds)');ylabel('error in sway (meters)');set_font

subplot(3,1,3)
plot(Test4noWFeta.time,Test4noWFeta.signals.values(:,3)-Test4WFeta.signals.values(:,3))
xlabel('Time (seconds)');ylabel('error in yaw (deg)');set_font
saveas(gcf, 'figures\WFCase\Test4_eta', 'fig')
set(gcf,'PaperUnits','inches','PaperPosition',2.66*[0 0 4 3])
print -dpng plots\WFCase4eta.png -r300
 
%% ISE
format short g
%Separate each case with NaN's
ISE_WF=[ISE_Test1WF_eta'./ISE_Test1noWF_eta',Test1WFmax(4)/Test1noWFmax(4)...
     ISE_Test1WF_tau'./ISE_Test1noWF_tau';
     ISE_Test1WFpost_eta'./ISE_Test1noWF_eta',Test1WFpostmax(4)/Test1noWFmax(4)...
     ISE_Test1WFpost_tau'./ISE_Test1noWF_tau';
     NaN,NaN,NaN,NaN,NaN,NaN,NaN; 
     ISE_Test2WF_eta'./ISE_Test2noWF_eta',Test2WFmax(4)/Test2noWFmax(4)...
     ISE_Test2WF_tau'./ISE_Test2noWF_tau';
     ISE_Test2WFpost_eta'./ISE_Test2noWF_eta',Test2WFpostmax(4)/Test2noWFmax(4)...
     ISE_Test2WFpost_tau'./ISE_Test2noWF_tau';
     NaN,NaN,NaN,NaN,NaN,NaN,NaN;  
     ISE_Test3WF_eta'./ISE_Test3noWF_eta',Test3WFmax(4)/Test3noWFmax(4)...
     ISE_Test3WF_tau'./ISE_Test3noWF_tau';
     ISE_Test3WFpost_eta'./ISE_Test3noWF_eta',Test3WFpostmax(4)/Test3noWFmax(4)...
     ISE_Test3WFpost_tau'./ISE_Test3noWF_tau';
     NaN,NaN,NaN,NaN,NaN,NaN,NaN; 
     ISE_Test4WFsel_eta'./ISE_Test4noWF_eta',Test4WFselmax(4)/Test4noWFmax(4)...
     ISE_Test4WFsel_tau'./ISE_Test4noWF_tau';
     ISE_Test4WFselpost_eta'./ISE_Test4noWF_eta',Test4WFselpostmax(4)/Test4noWFmax(4)...
     ISE_Test4WFselpost_tau'./ISE_Test4noWF_tau';]
 
matrix2lyx(ISE_WF, 'ISE_WF.lyx')
%%
clear total_error max_error eta tau_actual ISE_thruster ISE_eta tout...
      h_legend