%% Calculate available thrust limits
%
% Created by Christoffer Ofstad, 20.01.2014

%Thruster time constant
constants.thruster.T_thrust=10;

%Thruster Positions (x,y,z)
p_bow_tunnel=   [34.3;0;0];
p_bow_azi=      [29.4;0;0];
p_aft_tunnel=   [-35.6;0;0];
p_port_main=    [-39.6;-3.9;0];
p_stbrd_main=   [-39.6;4.1;0];

%Thruster forces [Ton]
F_bow_tunnel=           [0;13.7;0];
F_bow_azi=              [16.3;16.3;0];
F_aft_tunnel=           [0;-13.7;0];
F_port_main=            [35.9;0;0];
F_port_main_reverse=    [-21;0;0];
F_stbrd_main=           [35.9;0;0];
F_stbrd_main_reverse=   [-21;0;0];
F_port_rudder=          [0;15.5;0];
F_stbrd_rudder=         [0;15.5;0];

%Find maximum thrust                        
max_thrust=(F_port_main+F_stbrd_main+F_bow_tunnel+F_bow_azi-F_aft_tunnel...
            +F_port_rudder+F_stbrd_rudder+...
            cross(p_bow_tunnel,F_bow_tunnel)+cross(p_bow_azi,F_bow_azi)+...
            cross(p_aft_tunnel,F_aft_tunnel)+...
            max(cross(p_port_main,-F_port_rudder),...
            cross(p_port_main,F_port_main))+...
            max(cross(p_stbrd_main,-F_stbrd_rudder),...
            cross(p_stbrd_main,F_stbrd_main)))*9806.65;

%Find minimum thrust  
min_thrust=(F_port_main_reverse+F_stbrd_main_reverse-F_bow_tunnel-...
            F_bow_azi+F_aft_tunnel-F_port_rudder-F_stbrd_rudder+...
            cross(p_bow_tunnel,-F_bow_tunnel)+...
            cross(p_bow_azi,-F_bow_azi)+...
            cross(p_aft_tunnel,-F_aft_tunnel)+...
            min(cross(p_port_main,F_port_rudder),...
            cross(p_port_main,F_port_main_reverse))+...
            min(cross(p_stbrd_main,F_stbrd_rudder),...
            cross(p_stbrd_main,F_stbrd_main_reverse)))*9806.65;
%Assign parameters in each DOF
constants.thruster.F_surge_max=[1 0 0]*max_thrust;
constants.thruster.F_surge_min=[1 0 0]*min_thrust;
constants.thruster.F_sway_max=[0 1 0]*max_thrust;
constants.thruster.F_sway_min=[0 1 0]*min_thrust;
constants.thruster.F_yaw_max=[0 0 1]*max_thrust;
constants.thruster.F_yaw_min=[0 0 1]*min_thrust;

clear p_bow_tunnel p_bow_azi p_aft_tunnel p_port_main p_stbrd_main ...
      F_bow_tunnel F_bow_azi F_aft_tunnel F_port_main...
      F_port_main_reverse F_stbrd_main F_stbrd_main_reverse...
      F_port_rudder F_stbrd_rudder max_thrust min_thrust