%% Predictive simulation, heading vs point of impact contour plots
%
% Created by: Christoffer Ofstad 20.02.2014
%
%% Init
clear
%Real Ice Force applied
F_ice=4e4;
displacement=[4 9];
AoA_ice=80;
constants.real_ice.force=pred_force(-F_ice,displacement,AoA_ice);
constants.real_ice.timeon=400;

%% Initialize test parameters
delta=5;
d_pred=displacement; 
t=2.5;
gamma=2.25;
constants.pred.timeoff=constants.real_ice.timeon;
simulation_model = ('sim_prediction_report_test'); 
sim_length=700;
init
find_available_thrust

%Find error without prediction
constants.pred.force=pred_force(0,[0 0],0);
constants.pred.timeon=0;
sim(simulation_model);
[total_error_no_pred, ~] = error_sampling(eta, ISE_eta);

%Initialize limits for heading
a0=AoA_ice-40;
af=AoA_ice+40;
a=a0:(af-a0)/(delta-1):af;

%Initialize limits for predicted position of impact
p0=-20;
pf=20;
p=p0:(pf-p0)/(delta-1):pf;


%% Time vs Force
%Initialize error vector
error_pos=zeros(delta);
error_head=zeros(delta);
count=0;
start_time=tic;
for i=1:length(a)
    for j=1:length(p)
        constants.pred.force=pred_force(gamma*F_ice,(displacement+[p(j) 9]),a(i));
        constants.pred.timeon=constants.pred.timeoff-t;
        %Simulation
        sim_start=tic;
        sim(simulation_model);
        sim_time=toc(sim_start);
        [total_error, ~] = error_sampling(eta, ISE_eta);
        error_pos(i,j)=total_error(4)/total_error_no_pred(4);
        error_head(i,j)=total_error(3)/total_error_no_pred(3);
        count=count+1;
        clc
        string = [num2str(round(100*((count)/(length(a)*length(p))))),'% complete'];
        string2= [secs2hms(abs(sim_time*(length(a)*length(p))-toc(start_time))),' remaining'];
        disp(string);
        disp(string2);
    end
end

figure(33)
contour3(a,p,error_pos,1000)
xlabel('\theta_p (degrees)');ylabel('[d_p 9]');zlabel('position error ratio')
set_font

figure(44)
contour3(a,p,error_head,1000)
xlabel('\theta_p (degrees)');ylabel('[d_p 9]');zlabel('heading error ratio')
set_font
% set(gcf,'PaperUnits','inches','PaperPosition',[0 0 6 6])
% print -dbmp filename.bmp -r80
